# Replicating the RIFL Developer Study

This page contains materials for replicating the developer study presented in our paper, _Robust Programs with Filtered Iterators_.
The complete artifact is available [online](http://people.csail.mit.edu/jiasi/sle2017_rifl_artifact/).

## Experimental Design

Section 4 of the paper presents the design, analysis, and results of the study. Here we present the instrumentations that we developed for conducting the experiments.

* Starter files
  - Control:
    [Tutorial](instrumentation/control/starter/prog0.stu)
    [Task1](instrumentation/control/starter/prog1.stu)
    [Task2](instrumentation/control/starter/prog2.stu)
    [Task3](instrumentation/control/starter/prog3.stu)
  - Inspect:
    [Tutorial](instrumentation/inspect/starter/prog0.stu)
    [Task1](instrumentation/inspect/starter/prog1.stu)
    [Task2](instrumentation/inspect/starter/prog2.stu)
    [Task3](instrumentation/inspect/starter/prog3.stu)
  - Sample inputs (same for both groups):
    [Tutorial](instrumentation/inspect/starter/input0.txt)
    [Task1](instrumentation/inspect/starter/input1.txt)
    [Task2](instrumentation/inspect/starter/input2.txt)
    [Task3](instrumentation/inspect/starter/input3.txt)
* Virtual machines with RIFL implementations (download links)
  - Control: [VM](http://people.csail.mit.edu/jiasi/sle2017_rifl_artifact/developer_study_vm_control_group.zip)
  - Inspect: [VM](http://people.csail.mit.edu/jiasi/sle2017_rifl_artifact/developer_study_vm_inspect_group.zip)
* Reading materials
  - [Consent form](instrumentation/consent.pdf)
  - Control:
    [Manual](instrumentation/control/reading/manualc.pdf)
    [Instructions](instrumentation/control/reading/instructionc.pdf)
    [Solutions](instrumentation/control/reading/solutionsc.pdf)
  - Inspect:
    [Manual1](instrumentation/inspect/reading/tutorial.pdf)
    [Manual2](instrumentation/inspect/reading/manuali.pdf)
    [Instructions](instrumentation/inspect/reading/instructioni.pdf)
    [Solutions](instrumentation/inspect/reading/solutionsi.pdf)

## Raw Data

Here we present the raw data that we collected from the experiments.

* Program files
  - Control:
    [c1](raw/file/c1/)
    [c2](raw/file/c2/)
    [c3](raw/file/c3/)
    [c4](raw/file/c4/)
    [c5](raw/file/c5/)
  - Inspect:
    [i1](raw/file/i1/)
    [i2](raw/file/i2/)
    [i3](raw/file/i3/)
    [i4](raw/file/i4/)
    [i5](raw/file/i5/)
* Screencasts for both groups (download link): [screencasts](http://people.csail.mit.edu/jiasi/sle2017_rifl_artifact/developer_study_screencasts.zip)
* Booklets
  - Control:
    [c1](raw/booklet/c1.pdf)
    [c2](raw/booklet/c2.pdf)
    [c3](raw/booklet/c3.pdf)
    [c4](raw/booklet/c4.pdf)
    [c5](raw/booklet/c5.pdf)
  - Inspect:
    [i1](raw/booklet/i1.pdf)
    [i2](raw/booklet/i2.pdf)
    [i3](raw/booklet/i3.pdf)
    [i4](raw/booklet/i4.pdf)
    [i5](raw/booklet/i5.pdf)

## Analysis

As discussed in the paper, we analyze the thumbnail programs in files named `prog3.stu`. Section IV of the paper presents how to measure defects and program complexity from the source code. Here we present test inputs and program outputs.

* [Test inputs](analysis/input/) (same for both groups)
* Program outputs
  - Control:
    [c1](analysis/output/c1.out)
    [c2](analysis/output/c2.out)
    [c3](analysis/output/c3.out)
    [c4](analysis/output/c4.out)
    [c5](analysis/output/c5.out)
  - Inspect:
    [i1](analysis/output/i1.out)
    [i2](analysis/output/i2.out)
    [i3](analysis/output/i3.out)
    [i4](analysis/output/i4.out)
    [i5](analysis/output/i5.out)
